@@ -36,9 +36,13 @@ from gettext import gettext as _
 from gnomemusic.window import Window
 from gnomemusic.mpris import MediaPlayer2Service
 from gnomemusic.notification import NotificationManager
+from gnomemusic import log
+import logging
+logger = logging.getLogger(__name__)
 
 
 class Application(Gtk.Application):
+    @log
     def __init__(self):
         Gtk.Application.__init__(self,
                                  application_id='org.gnome.Music',
@@ -55,6 +59,7 @@ class Application(Gtk.Application):
 
         self._window = None
 
+    @log
     def build_app_menu(self):
         builder = Gtk.Builder()
 
@@ -79,12 +84,15 @@ class Application(Gtk.Application):
         quitAction.connect('activate', self.quit)
         self.add_action(quitAction)
 
+    @log
     def new_playlist(self, action, param):
         pass
 
+    @log
     def help(self, action, param):
         Gtk.show_uri(None, "help:gnome-music", Gdk.CURRENT_TIME)
 
+    @log
     def about(self, action, param):
         builder = Gtk.Builder()
         builder.add_from_resource('/org/gnome/Music/AboutDialog.ui')
@@ -93,9 +101,11 @@ class Application(Gtk.Application):
         about.connect("response", self.about_response)
         about.show()
 
+    @log
     def about_response(self, dialog, response):
         dialog.destroy()
 
+    @log
     def do_startup(self):
         Gtk.Application.do_startup(self)
 
@@ -103,6 +113,7 @@ class Application(Gtk.Application):
 
         self.build_app_menu()
 
+    @log
     def quit(self, action=None, param=None):
         self._window.destroy()
 
