@@ -48,6 +48,10 @@ class Query():
     def all_songs():
         return Query.songs('?song a nmm:MusicPiece ; a nfo:FileDataObject .')
 
+    @staticmethod
+    def all_playlists():
+        return Query.playlists('?playlist a nmm:Playlist .')
+
     @staticmethod
     def all_songs_count():
         query = '''
@@ -401,6 +405,42 @@ class Query():
 
         return query
 
+    @staticmethod
+    def playlists(where_clause):
+        query = '''
+    SELECT DISTINCT
+        rdf:type(?playlist)
+        tracker:id(?playlist) AS id
+        nie:title(?playlist) AS title
+        nfo:entryCounter(?playlist) AS childcount
+        {
+            %(where_clause)s
+            OPTIONAL {
+                ?playlist a nfo:FileDataObject .
+                FILTER (
+                    EXISTS {
+                        ?playlist tracker:available 'true'
+                        FILTER (
+                            tracker:uri-is-descendant(
+                                '%(music_dir)s', nie:url(?playlist)
+                            ) ||
+                            tracker:uri-is-descendant(
+                                '%(download_dir)s', nie:url(?playlist)
+                            )
+                        )
+                    }
+                )
+            }
+        }
+    ORDER BY fn:lower-case(?title) ?author ?albumyear
+    '''.replace('\n', ' ').strip() % {
+            'where_clause': where_clause.replace('\n', ' ').strip(),
+            'music_dir': Query.MUSIC_DIR,
+            'download_dir': Query.DOWNLOAD_DIR
+        }
+
+        return query
+
     @staticmethod
     def album_songs(album_id):
         query = '''
@@ -448,6 +488,50 @@ class Query():
 
         return query
 
+    @staticmethod
+    def playlist_songs(playlist_id, filter_clause=None):
+        query = '''
+    SELECT
+        rdf:type(?song)
+        tracker:id(?entry) AS id
+        nie:url(?song) AS url
+        nie:title(?song) AS title
+        nmm:artistName(nmm:performer(?song)) AS artist
+        nie:title(nmm:musicAlbum(?song)) AS album
+        nfo:duration(?song) AS duration
+    WHERE {
+        ?playlist a nmm:Playlist ;
+            a nfo:MediaList ;
+            nfo:hasMediaFileListEntry ?entry .
+        ?entry a nfo:MediaFileListEntry ;
+            nfo:entryUrl ?url .
+        ?song a nmm:MusicPiece ;
+             a nfo:FileDataObject ;
+             nie:url ?url .
+        FILTER (
+            %(filter_clause)s
+        )
+        FILTER (
+            NOT EXISTS {
+                ?song a nmm:Video
+            } &&
+            NOT EXISTS {
+                ?song a nmm:Playlist
+            }
+        )
+    }
+    ORDER BY
+         nfo:listPosition(?entry)
+    '''.replace('\n', ' ').strip() % {
+            'playlist_id': playlist_id,
+            'filter_clause':
+                filter_clause or 'tracker:id(?playlist) = ' + playlist_id,
+            'music_dir': Query.MUSIC_DIR,
+            'download_dir': Query.DOWNLOAD_DIR
+        }
+
+        return query
+
     @staticmethod
     def get_album_for_album_id(album_id):
         query = """
@@ -524,33 +608,196 @@ class Query():
         return query
 
     @staticmethod
-    def get_song_with_url(url):
-        query = '''
-    SELECT DISTINCT
-        rdf:type(?song)
-        tracker:id(?song) AS id
-        nie:url(?song) AS url
-        nie:title(?song) AS title
-        nmm:artistName(nmm:performer(?song)) AS artist
-        nie:title(nmm:musicAlbum(?song)) AS album
-        nfo:duration(?song) AS duration
-    WHERE {
-        ?song a nmm:MusicPiece ;
-              nie:url "%(url)s"
-        FILTER (
-            NOT EXISTS {
-                ?song a nmm:Video
-            } &&
-            NOT EXISTS {
-                ?song a nmm:Playlist
-            }
-        )
+    def create_playlist(title):
+        query = """
+    INSERT {
+        _:playlist
+            a nmm:Playlist ;
+            a nfo:MediaList ;
+            nie:title "%(title)s" ;
+            nfo:entryCounter 0 .
     }
-    '''.replace('\n', ' ').strip() % {'url': url}
+    """.replace("\n", " ").strip() % {
+            'title': title
+        }
         return query
 
-    #Functions for search
-    # TODO: make those queries actualyl return something
+    @staticmethod
+    def delete_playlist(playlist_id):
+        query = """
+    DELETE {
+        ?playlist
+            a rdfs:Resource .
+        ?entry
+            a rdfs:Resource .
+    }
+    WHERE {
+        ?playlist
+            a nmm:Playlist ;
+            a nfo:MediaList .
+        OPTIONAL {
+            ?playlist
+                nfo:hasMediaFileListEntry ?entry .
+        }
+        FILTER (
+            tracker:id(?playlist) = %(playlist_id)s
+        )
+    }
+    """.replace("\n", " ").strip() % {
+            'playlist_id': playlist_id
+        }
+        return query
+
+    @staticmethod
+    def add_song_to_playlist(playlist_id, song_uri):
+        query = """
+    INSERT OR REPLACE {
+        _:entry
+            a nfo:MediaFileListEntry ;
+            nfo:entryUrl "%(song_uri)s" ;
+            nfo:listPosition ?position .
+        ?playlist
+            nfo:entryCounter ?position ;
+            nfo:hasMediaFileListEntry _:entry .
+    }
+    WHERE {
+        SELECT
+            ?playlist
+            (?counter + 1) AS position
+        WHERE {
+            ?playlist
+                a nmm:Playlist ;
+                a nfo:MediaList ;
+                nfo:entryCounter ?counter .
+            FILTER (
+                tracker:id(?playlist) = %(playlist_id)s
+            )
+        }
+    }
+    """.replace("\n", " ").strip() % {
+            'playlist_id': playlist_id,
+            'song_uri': song_uri
+        }
+        return query
+
+    @staticmethod
+    def remove_song_from_playlist(playlist_id, song_id):
+        query = """
+    INSERT OR REPLACE {
+        ?entry
+            nfo:listPosition ?position .
+    }
+    WHERE {
+        SELECT
+            ?entry
+            (?old_position - 1) AS position
+        WHERE {
+            ?entry
+                a nfo:MediaFileListEntry ;
+                nfo:listPosition ?old_position .
+            ?playlist
+                nfo:hasMediaFileListEntry ?entry .
+            FILTER (?old_position > ?removed_position)
+            {
+                SELECT
+                    ?playlist
+                    ?removed_position
+                WHERE {
+                    ?playlist
+                        a nmm:Playlist ;
+                        a nfo:MediaList ;
+                        nfo:hasMediaFileListEntry ?removed_entry .
+                    ?removed_entry
+                        nfo:listPosition ?removed_position .
+                    FILTER (
+                        tracker:id(?playlist) = %(playlist_id)s &&
+                        tracker:id(?removed_entry) = %(song_id)s
+                    )
+                }
+            }
+        }
+    }
+    INSERT OR REPLACE {
+        ?playlist
+            nfo:entryCounter ?new_counter .
+    }
+    WHERE {
+        SELECT
+            ?playlist
+            (?counter - 1) AS new_counter
+        WHERE {
+            ?playlist
+                a nmm:Playlist ;
+                a nfo:MediaList ;
+                nfo:entryCounter ?counter .
+            FILTER (
+                tracker:id(?playlist) = %(playlist_id)s
+            )
+        }
+    }
+    DELETE {
+        ?playlist
+            nfo:hasMediaFileListEntry ?entry .
+        ?entry
+            a rdfs:Resource .
+    }
+    WHERE {
+        ?playlist
+            a nmm:Playlist ;
+            a nfo:MediaList ;
+            nfo:hasMediaFileListEntry ?entry .
+        FILTER (
+            tracker:id(?playlist) = %(playlist_id)s &&
+            tracker:id(?entry) = %(song_id)s
+        )
+    }
+    """.replace("\n", " ").strip() % {
+            'playlist_id': playlist_id,
+            'song_id': song_id
+        }
+        return query
+
+    @staticmethod
+    def get_playlist_with_id(playlist_id):
+        query = """
+    ?playlist a nmm:Playlist .
+    FILTER (
+        tracker:id(?playlist) = %(playlist_id)s
+    )
+    """.replace('\n', ' ').strip() % {'playlist_id': playlist_id}
+
+        return Query.playlists(query)
+
+    @staticmethod
+    def get_playlist_with_urn(playlist_urn):
+        query = """
+    SELECT DISTINCT
+        tracker:id(<%(playlist_urn)s>) AS id
+    WHERE {
+        <%(playlist_urn)s> a nmm:Playlist
+    }
+    """.replace('\n', ' ').strip() % {'playlist_urn': playlist_urn}
+        return query
+
+    @staticmethod
+    def get_playlist_song_with_id(playlist_id, entry_id):
+        return Query.playlist_songs(
+            playlist_id, 'tracker:id(?entry) = ' + str(entry_id)
+        )
+
+    @staticmethod
+    def get_playlist_song_with_urn(entry_urn):
+        query = """
+    SELECT DISTINCT
+        tracker:id(<%(entry_urn)s>) AS id
+    WHERE {
+        <%(entry_urn)s> a nfo:MediaFileListEntry
+    }
+    """.replace('\n', ' ').strip() % {'entry_urn': entry_urn}
+        return query
+
+    # Functions for search
+    # TODO: make those queries actually return something
     @staticmethod
     def get_albums_with_any_match(name):
         name = Tracker.sparql_escape_string(GLib.utf8_casefold(name, -1))
