@@ -52,10 +52,7 @@ except Exception as e:
     exit(1)
 
 ALBUM_ART_CACHE = AlbumArtCache.get_default()
-if Gtk.Widget.get_default_direction() is not Gtk.TextDirection.RTL:
-    NOW_PLAYING_ICON_NAME = 'media-playback-start-symbolic'
-else:
-    NOW_PLAYING_ICON_NAME = 'media-playback-start-rtl-symbolic'
+NOW_PLAYING_ICON_NAME = 'media-playback-start-symbolic'
 ERROR_ICON_NAME = 'dialog-error-symbolic'
 
 
