@@ -196,7 +196,13 @@ class Window(Gtk.ApplicationWindow):
         self._box.pack_start(self.selection_toolbar.actionbar, False, False, 0)
         self.add(self._box)
         count = 1
-        cursor = tracker.query(Query.all_songs_count(), None)
+        cursor = None
+        try:
+            cursor = tracker.query(Query.all_songs_count(), None)
+        except Exception as e:
+            logger.error("Tracker query crashed: %s" % e)
+            count = 0
+
         if cursor is not None and cursor.next(None):
             count = cursor.get_integer(0)
         if count > 0:
